@@ -58,18 +58,19 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "a00674.html",
-"a00912.html#a33f9830228f847fae1c30c9dffe02b5a",
-"a00957.html#aa7e32ce7ba896c5ddfe6521ad0022ce2",
-"a00993.html#a1d27edb01bfb68ba50776b25aa437783",
-"a01025.html#a19202138f911782b5652536867d24565",
-"a01077.html#aa71d36872f416feaa853788a7a7a7ef8",
-"a01121.html#ac5eadebfdd9b11ac383653e5a2383231",
-"a01169.html#a6a642b61f5cf7ced73523798467735a5",
-"a01213.html#ad9941ba7019b0fd8aad6e9321d91c26a",
-"a01269.html#a15628b18e19d90e91fdbd659925ae5c0",
-"a01309.html#a77cee40767fd4936f20a8f9d9d9ea625",
-"a01341.html#ab38c56ce6121aed94f2796bf5df894be"
+"a00912.html#a64a4b29d36851a8d83be05af5b25f886",
+"a00952.html#a8f84862ac65dcdc8cd9063b0264b711f",
+"a00984.html#a68a029efbad55b2fd991d29aa37a7c28",
+"a01032.html#a8a146d5966d7372bdd2557e990e52adc",
+"a01084.html",
+"a01120.html#a5ef292b43e4824968e72d664012be93f",
+"a01164.html#a9ca8e987a5e8ac5bbd66f46bf2fc419c",
+"a01212.html#a35609a9d5a1b087bd675035d710dc688",
+"a01260.html#a6f1841c958530d57dca2cf8e449623cc",
+"a01304.html#ac84ff682fda703f1f552a05977050f20",
+"a01324.html#a61e933f9a128cb16d31611fd96ecd153"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
+var LISTOFALLMEMBERS = 'List of all members';
\ No newline at end of file
